<p align="center">
  <img src="Screenshots/LogoAndText.png">  
</p>


<hr>

## What Is A Linux Rice ?

A R.I.C.E (Race Inspired Cosmetic Enhancements) according to the urban dictionary is 
> "Parts put on cars to make them look fast"

In linux terms 'rice' is used to describe a person's unix desktop where someone has customized their desktop such as the icons, panels, or system interface. A great place to find different linux rice is the [r/unixporn](https://www.reddit.com/r/unixporn) subreddit.

<hr>

## Why This Apps Exists ?

Setting up a rice takes a lot of work. You need to install, copy the themes to their specific folders and if you find a rice you like it could be hard copying the file to the specific place if you're a noob in ricing. Wouldnt it be simple if you could just download one file which you can install on your system with one click without wasting your time copy pasting the several dotfiles and setting up the rice. For more information take a look at the [wiki](https://github.com/techcoder20/themesaver/wiki)

<hr>

## Installation

If the app has intrigued you you can install it by running this command in a terminal to install themesaver.

***Note:*** Only the following Desktop environments and Windows Managers are supported:
- xfce
- xfwm4
- plasma
- kde
- kwin
- qtile
- gnome
- gnome shell
- awesome
- i3

```
wget -qO- https://raw.githubusercontent.com/techcoder20/ThemeSaver/main/install.py | python3
```

<details>
<summary>To Install Manually</summary>
To manually install ThemeSaver:
 
```
sudo git clone https://github.com/techcoer20/themesaver /opt/themesaver
python3 /opt/themesaver/install.py
```
</details>

<details>
<summary>Uninstallation</summary>
If you dont like themesaver for some reason you can uninstall by running this command in a terminal.

```
python3 /opt/themesaver/uninstall.py
```

</details>

<hr>

## Credits

<b>I got the icons for the app from flaticon.com so here are the attributes for them :)</b>

<div>Icons made by <a href="https://www.freepik.com" title="Freepik">Freepik</a> from <a href="https://www.flaticon.com/" title="Flaticon">www.flaticon.com</a></div>
<div>Icons made by <a href="https://www.flaticon.com/authors/bqlqn" title="bqlqn">bqlqn</a> from <a href="https://www.flaticon.com/" title="Flaticon">www.flaticon.com</a></div>
<div>Icons made by <a href="https://www.flaticon.com/authors/chanut" title="Chanut">Chanut</a> from <a href="https://www.flaticon.com/" title="Flaticon">www.flaticon.com</a></div>
<div>Icons made by <a href="https://www.flaticon.com/authors/kiranshastry" title="Kiranshastry">Kiranshastry</a> from <a href="https://www.flaticon.com/" title="Flaticon">www.flaticon.com</a></div>
<div>Icons made by <a href="https://www.flaticon.com/authors/pixel-perfect" title="Pixel perfect">Pixel perfect</a> from <a href="https://www.flaticon.com/" title="Flaticon">www.flaticon.com</a></div>       
   
   
This app was inspired by: https://github.com/paju1986/PlasmaConfSaver

<hr>
